@@ -268,7 +268,7 @@ namespace kt
 				resort = true;
 			
 			if (modified && !resort)
-				emit dataChanged(index(idx,3),index(idx,15));
+				Q_EMIT dataChanged(index(idx,3),index(idx,15));
 			idx++;
 		}
 	
@@ -384,7 +384,7 @@ namespace kt
 	bt::PeerInterface* PeerViewModel::indexToPeer(const QModelIndex & index)
 	{
 		if (!index.isValid() || index.row() >= items.count() || index.row() < 0)
-			return 0; 
+			return nullptr; 
 		else
 			return ((Item*)index.internalPointer())->peer;
 	}
@@ -411,8 +411,8 @@ namespace kt
 	{
 		sort_column = col;
 		sort_order = order;
-		emit layoutAboutToBeChanged();
+		Q_EMIT layoutAboutToBeChanged();
 		std::stable_sort(items.begin(),items.end(),PeerViewModelItemCmp(col, order));
-		emit layoutChanged();
+		Q_EMIT layoutChanged();
 	}
 }
